@@ -30,7 +30,7 @@ class IllegalArgumentError(Exception):
 
 
 class APIManager(object):
-    """Provides a method for creating a public ReSTful JSOn API with respect to
+    """Provides a method for creating a public ReSTful JSON API with respect to
     a given :class:`~flask.Flask` application object.
 
     The :class:`~flask.Flask` object can be specified in the constructor, or
@@ -38,6 +38,41 @@ class APIManager(object):
     case, the application object must be specified before calling the
     :meth:`create_api` method.
 
+    `app` is the :class:`flask.Flask` object containing the user's Flask
+    application.
+
+    `session` is the :class:`sqlalchemy.orm.session.Session` object in which
+    changes to the database will be made.
+
+    `flask_sqlalchemy_db` is the :class:`flask.ext.sqlalchemy.SQLAlchemy`
+    object with which `app` has been registered and which contains the
+    database models for which API endpoints will be created.
+
+    If `flask_sqlalchemy_db` is not ``None``, `session` will be ignored.
+
+    For example, to use this class with models defined in pure SQLAlchemy::
+
+        from flask import Flask
+        from flask.ext.restless import APIManager
+        from sqlalchemy import create_engine
+        from sqlalchemy.orm.session import sessionmaker
+
+        engine = create_engine('sqlite:////tmp/mydb.sqlite')
+        Session = sessionmaker(bind=engine)
+        mysession = Session()
+        app = Flask(__name__)
+        apimanager = APIManager(app, session=mysession)
+
+    and with models defined with Flask-SQLAlchemy::
+
+        from flask import Flask
+        from flask.ext.restless import APIManager
+        from flask.ext.sqlalchemy import SQLAlchemy
+
+        app = Flask(__name__)
+        db = SQLALchemy(app)
+        apimanager = APIManager(app, flask_sqlalchemy_db=db)
+
     """
 
     #: The format of the name of the API view for a given model.
@@ -57,51 +92,6 @@ class APIManager(object):
     BLUEPRINTNAME_FORMAT = '%s%s'
 
     def __init__(self, app=None, session=None, flask_sqlalchemy_db=None):
-        """Stores the specified :class:`flask.Flask` application object on
-        which API endpoints will be registered.
-
-        If `app` is ``None`` or one of `session` and `flask_sqlalchemy_db_` is
-        ``None``, the user must call the :meth:`init_app` method before calling
-        the :meth:`create_api` method.
-
-        `app` is the :class:`flask.Flask` object containing the user's Flask
-        application.
-
-        `session` is the :class:`session.orm.session.Session` object in which
-        changes to the database will be made. It may also be a
-        :class:`session.orm.session.Session` class, in which case a new
-        :class:`sqlalchemy.orm.scoped_session` will be created from it.
-
-        `flask_sqlalchemy_db` is the :class:`flask.ext.sqlalchemy.SQLAlchemy`
-        object with which `app` has been registered and which contains the
-        database models for which API endpoints will be created.
-
-        If `flask_sqlalchemy_db` is not ``None``, `session` will be ignored.
-
-        For example, to use this class with models defined in pure SQLAlchemy::
-
-            from flask import Flask
-            from flask.ext.restless import APIManager
-            from sqlalchemy import create_engine
-            from sqlalchemy.orm.session import sessionmaker
-
-            engine = create_engine('sqlite:////tmp/mydb.sqlite')
-            Session = sessionmaker(bind=engine)
-            mysession = Session()
-            app = Flask(__name__)
-            apimanager = APIManager(app, session=mysession)
-
-        and with models defined with Flask-SQLAlchemy::
-
-            from flask import Flask
-            from flask.ext.restless import APIManager
-            from flask.ext.sqlalchemy import SQLAlchemy
-
-            app = Flask(__name__)
-            db = SQLALchemy(app)
-            apimanager = APIManager(app, flask_sqlalchemy_db=db)
-
-        """
         self.init_app(app, session, flask_sqlalchemy_db)
 
     def _next_blueprint_name(self, basename):
@@ -137,8 +127,8 @@ class APIManager(object):
         :class:`sqlalchemy.orm.session.Session` object in which all database
         changes will be made.
 
-        `session` is the :class:`session.orm.session.Session` object in which
-        changes to the database will be made.
+        `session` is the :class:`sqlalchemy.orm.session.Session` object in
+        which changes to the database will be made.
 
         `flask_sqlalchemy_db` is the :class:`flask.ext.sqlalchemy.SQLAlchemy`
         object with which `app` has been registered and which contains the
@@ -188,8 +178,6 @@ class APIManager(object):
     def create_api_blueprint(self, model, methods=READONLY_METHODS,
                              url_prefix='/api', collection_name=None,
                              allow_patch_many=False, allow_functions=False,
-                             authentication_required_for=None,
-                             authentication_function=None,
                              exclude_columns=None, include_columns=None,
                              validation_exceptions=None, results_per_page=10,
                              max_results_per_page=100,
@@ -214,9 +202,8 @@ class APIManager(object):
         object specified in the constructor of this class, so you do *not* need
         to register it yourself.
 
-        `model` is the :class:`flask.ext.restless.Entity` class for which a
-        ReSTful interface will be created. Note this must be a class, not an
-        instance of a class.
+        `model` is the SQLAlchemy model class for which a ReSTful interface
+        will be created. Note this must be a class, not an instance of a class.
 
         `methods` specify the HTTP methods which will be made available on the
         ReSTful API for the specified model, subject to the following caveats:
@@ -261,17 +248,6 @@ class APIManager(object):
         if ``False`` by default. Warning: you must not create an API for a
         model whose name is ``'eval'`` if you set this argument to ``True``.
 
-        `authentication_required_for` is a list of HTTP method names (for
-        example, ``['POST', 'PATCH']``) for which authentication must be
-        required before clients can successfully make requests. If this keyword
-        argument is specified, `authentication_function` must also be
-        specified. For more information on requiring authentication, see
-        :ref:`authentication`.
-
-        `authentication_function` is a function which accepts no arguments and
-        returns ``True`` if and only if a client is authorized to make a
-        request on an endpoint.
-
         If either `include_columns` or `exclude_columns` is not ``None``,
         exactly one of them must be specified. If both are not ``None``, then
         this function will raise a :exc:`IllegalArgumentError`.
@@ -333,6 +309,13 @@ class APIManager(object):
         other code. For more information on preprocessors and postprocessors,
         see :ref:`processors`.
 
+        .. versionchanged:: 0.10.0
+           Removed `authentication_required_for` and `authentication_function`
+           keyword arguments.
+
+           Use the `preprocesors` and `postprocessors` keyword arguments
+           instead. For more information, see :ref:`authentication`.
+
         .. versionadded:: 0.9.2
            Added the `preprocessors` and `postprocessors` keyword arguments.
 
@@ -362,10 +345,6 @@ class APIManager(object):
            Force the model name in the URL to lowercase.
 
         """
-        if authentication_required_for and not authentication_function:
-            msg = ('If authentication_required is specified, so must'
-                   ' authentication_function.')
-            raise IllegalArgumentError(msg)
         if exclude_columns is not None and include_columns is not None:
             msg = ('Cannot simultaneously specify both include columns and'
                    ' exclude columns.')
@@ -388,9 +367,7 @@ class APIManager(object):
         # the name of the API, for use in creating the view and the blueprint
         apiname = APIManager.APINAME_FORMAT % collection_name
         # the view function for the API for this model
-        api_view = API.as_view(apiname, self.session, model,
-                               authentication_required_for,
-                               authentication_function, exclude_columns,
+        api_view = API.as_view(apiname, self.session, model, exclude_columns,
                                include_columns, validation_exceptions,
                                results_per_page, max_results_per_page,
                                post_form_preprocessor, preprocessors,
@@ -406,14 +383,21 @@ class APIManager(object):
         blueprint = Blueprint(blueprintname, __name__, url_prefix=url_prefix)
         blueprint.add_url_rule(collection_endpoint,
                                methods=no_instance_methods, view_func=api_view)
-        blueprint.add_url_rule(collection_endpoint, defaults={'instid': None},
+        blueprint.add_url_rule(collection_endpoint,
+                               defaults={'instid': None, 'relationname': None},
                                methods=possibly_empty_instance_methods,
                                view_func=api_view)
         # the per-instance endpoints will allow both integer and string primary
         # key accesses
         instance_endpoint = '%s/<instid>' % (collection_endpoint)
         blueprint.add_url_rule(instance_endpoint, methods=instance_methods,
-                                   view_func=api_view)
+                               defaults={'relationname': None},
+                               view_func=api_view)
+        # add endpoints which expose related models
+        relation_endpoint = '%s/<relationname>' % (instance_endpoint)
+        blueprint.add_url_rule(relation_endpoint,
+                               methods=methods & frozenset(['GET']),
+                               view_func=api_view)
         # if function evaluation is allowed, add an endpoint at /api/eval/...
         # which responds only to GET requests and responds with the result of
         # evaluating functions on all instances of the specified model
